@@ -14,44 +14,9 @@ import matplotlib.pyplot as mpl
 import mpl_toolkits.axes_grid.parasite_axes as mpltk
 from astropy.extern import six
 
-WCS_TYPES = []
-HDU_TYPES = []
-HDULIST_TYPES = []
-
-# We need to be able to accept PyFITS objects if users have old scripts that
-# are reading FITS files with this instead of Astropy
-try:
-    import pyfits
-    HDU_TYPES.append(pyfits.PrimaryHDU)
-    HDU_TYPES.append(pyfits.ImageHDU)
-    HDU_TYPES.append(pyfits.CompImageHDU)
-    HDULIST_TYPES.append(pyfits.HDUList)
-    del pyfits
-except ImportError:
-    pass
-
-# Similarly, we need to accept PyWCS objects
-try:
-    import pywcs
-    WCS_TYPES.append(pywcs.WCS)
-    del pywcs
-except ImportError:
-    pass
-
-from astropy.io import fits
-HDU_TYPES.append(fits.PrimaryHDU)
-HDU_TYPES.append(fits.ImageHDU)
-HDU_TYPES.append(fits.CompImageHDU)
-HDULIST_TYPES.append(fits.HDUList)
-
 from astropy.wcs import WCS
-WCS_TYPES.append(WCS)
-del WCS
-
-# Convert to tuples so that these work when calling isinstance()
-HDU_TYPES = tuple(HDU_TYPES)
-HDULIST_TYPES = tuple(HDULIST_TYPES)
-WCS_TYPES = tuple(WCS_TYPES)
+from astropy.io import fits
+HDU_TYPES = (fits.PrimaryHDU, fits.ImageHDU, fits.CompImageHDU)
 
 import numpy as np
 
@@ -114,8 +79,6 @@ class FITSFigure(Layers, Regions, Deprecated):
                  string
                  astropy.io.fits.PrimaryHDU
                  astropy.io.fits.ImageHDU
-                 pyfits.PrimaryHDU
-                 pyfits.ImageHDU
                  astropy.wcs.WCS
                  np.ndarray
                  RGB image with AVM meta-data
@@ -224,7 +187,7 @@ class FITSFigure(Layers, Regions, Deprecated):
             data.nx = nx
             data.ny = ny
 
-        if isinstance(data, WCS_TYPES):
+        if isinstance(data, WCS):
             wcs = data
             if not hasattr(wcs, 'naxis1'):
                 raise aue.AstropyDeprecationWarning('WCS no longer stores information about NAXISn '
@@ -366,13 +329,13 @@ class FITSFigure(Layers, Regions, Deprecated):
 
             hdu = data
 
-        elif isinstance(data, HDULIST_TYPES):
+        elif isinstance(data, fits.HDUList):
 
             hdu = data[hdu]
 
         else:
 
-            raise Exception("data argument should either be a filename, an HDU object from astropy.io.fits or pyfits, a WCS object from astropy.wcs or pywcs, or a Numpy array.")
+            raise Exception("data argument should either be a filename, an HDU object from astropy.io.fits, a WCS object from astropy.wcs, or a Numpy array.")
 
         # Check that we have at least 2-dimensional data
         if hdu.header['NAXIS'] < 2:
@@ -836,8 +799,6 @@ class FITSFigure(Layers, Regions, Deprecated):
                  string
                  astropy.io.fits.PrimaryHDU
                  astropy.io.fits.ImageHDU
-                 pyfits.PrimaryHDU
-                 pyfits.ImageHDU
                  astropy.wcs.WCS
                  np.ndarray
 
@@ -975,8 +936,6 @@ class FITSFigure(Layers, Regions, Deprecated):
                  string
                  astropy.io.fits.PrimaryHDU
                  astropy.io.fits.ImageHDU
-                 pyfits.PrimaryHDU
-                 pyfits.ImageHDU
                  astropy.wcs.WCS
                  np.ndarray
 
@@ -987,8 +946,6 @@ class FITSFigure(Layers, Regions, Deprecated):
                  string
                  astropy.io.fits.PrimaryHDU
                  astropy.io.fits.ImageHDU
-                 pyfits.PrimaryHDU
-                 pyfits.ImageHDU
                  astropy.wcs.WCS
                  np.ndarray
 
@@ -1975,6 +1932,29 @@ class FITSFigure(Layers, Regions, Deprecated):
             >>> f.add_scalebar(0.01) # length has to be specified
             >>> f.scalebar.set_label('100 AU')
             >>> ...
+
+        Parameters
+        ----------
+
+        length : float, or quantity
+            The length of the scalebar in degrees, an angular quantity, or angular unit
+
+        label : str, optional
+            Label to place below the scalebar
+
+        corner : int, optional
+            Where to place the scalebar. Acceptable values are:, 'left',
+            'right', 'top', 'bottom', 'top left', 'top right', 'bottom
+            left' (default), 'bottom right'
+
+        frame : str, optional
+            Whether to display a frame behind the scalebar (default is False)
+
+        kwargs
+            Additional arguments are passed to the matplotlib Rectangle and
+            Text classes. See the matplotlib documentation for more details.
+            In cases where the same argument exists for the two objects, the
+            argument is passed to both the Text and Rectangle instance.
         '''
         if hasattr(self, 'scalebar'):
             raise Exception("Scalebar already exists")
@@ -2032,3 +2012,5 @@ class FITSFigure(Layers, Regions, Deprecated):
         Close the figure and free up the memory.
         '''
         mpl.close(self._figure)
+
+    savefig = save
