@@ -1,22 +1,23 @@
 import os
 import warnings
 
-import matplotlib
-matplotlib.use('Agg')
-
 import numpy as np
 from astropy.io import fits
+from astropy.tests.helper import pytest, remote_data
 
 from .. import FITSFigure
 from ..rgb import make_rgb_image
 
 from .test_images import BaseImageTests
+from . import baseline_dir
 
 HEADER = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'data/2d_fits', '1904-66_TAN.hdr')
 
 
 class TestRGB(BaseImageTests):
 
+    @remote_data
+    @pytest.mark.mpl_image_compare(baseline_dir=baseline_dir, tolerance=1.5)
     def test_rgb(self, generate, tmpdir):
 
         # Regression test to check that RGB recenter works properly
@@ -30,18 +31,18 @@ class TestRGB(BaseImageTests):
 
         header = fits.Header.fromtextfile(HEADER)
 
-        r = fits.PrimaryHDU(np.random.random((12,12)), header)
+        r = fits.PrimaryHDU(np.random.random((12, 12)), header)
         r.writeto(r_file)
 
-        g = fits.PrimaryHDU(np.random.random((12,12)), header)
+        g = fits.PrimaryHDU(np.random.random((12, 12)), header)
         g.writeto(g_file)
 
-        b = fits.PrimaryHDU(np.random.random((12,12)), header)
+        b = fits.PrimaryHDU(np.random.random((12, 12)), header)
         b.writeto(b_file)
 
         make_rgb_image([r_file, g_file, b_file], rgb_file, embed_avm_tags=False)
 
-        f = FITSFigure(r_file, figsize=(3,3))
+        f = FITSFigure(r_file, figsize=(3, 3))
 
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
@@ -52,5 +53,4 @@ class TestRGB(BaseImageTests):
 
         f.recenter(359.3, -72.1, radius=0.05)
 
-        self.generate_or_test(generate, f, 'test_rgb.png', tolerance=2)
-        f.close()
+        return f
